use datelevel_nov20.dta, clear

*** Generating graphs

twoway scatter country_position date if country=="DEU" & countrydate_u==1, ///
	connect(direct) tlabel(01feb2020 01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd)) ///
	ytitle("") xtitle("") subtitle("DEU", box bexpand fcolor(gs14))
graph save de_mean.gph, replace

twoway scatter country_position date if country=="ISR" & countrydate_u==1, ///
	connect(direct) tlabel(01feb2020 01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd)) ///
	ytitle("") xtitle("") subtitle("ISR", box bexpand fcolor(gs14))
graph save il_mean.gph, replace

twoway scatter country_position date if country=="NLD" & countrydate_u==1, ///
	connect(direct) tlabel(01feb2020 01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd)) ///
	ytitle("") xtitle("") subtitle("NLD", box bexpand fcolor(gs14))
graph save nl_mean.gph, replace

twoway scatter country_position date if country=="GBR" & countrydate_u==1, ///
	connect(direct) tlabel(01feb2020 01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd)) ///
	ytitle("") xtitle("") subtitle("UK", box bexpand fcolor(gs14))
graph save uk_mean.gph, replace

graph combine de_mean.gph uk_mean.gph il_mean.gph nl_mean.gph, ///
	col(2) ycommon xcommon l1title(Mean Opposition Behaviour)
graph save allcountries_covid_new.gph, replace
graph export allcountries_covid_new.png, replace

twoway (scatter date_position date, connect(direct) ///
		tlabel(01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd))) ///
		if country=="ISR", by(party_id, note("") title(Israel) holes(6)) ytitle(Opposition Party Behaviour) xtitle("")
graph save israel_covid.gph, replace
graph export israel_covid.png, replace

twoway (scatter date_position date, connect(direct) ///
		tlabel(01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd))) ///
		if country=="ISR" & party_id!=101 & party_id!=107 & party_id!=115 ///
		, by(party_id, note("") title(Israel)) ytitle(Party Behaviour) xtitle("")
graph save ilsubset_covid.gph, replace
graph export ilsubset_covid.png, replace

twoway (scatter date_position date, connect(direct) ///
		tlabel(01feb2020 01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd))) ///
		if country=="DEU", by(party_id, note("") title(Germany)) ytitle(Opposition Party Behaviour) xtitle("")
graph save germany_covid.gph, replace
graph export germany_covid.png, replace

twoway (scatter date_position date, connect(direct) ///
		tlabel(01feb2020 01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd))) ///
		if country=="NLD", by(party_id, note("") title(Netherlands)) ytitle(Opposition Party Behaviour) xtitle("")
graph save netherlands_covid.gph, replace
graph export netherlands_covid.png, replace

twoway (scatter date_position date, connect(direct) ///
		tlabel(01feb2020 01mar2020 01apr2020 01may2020 01june2020 01jul2020, format(%tdmd))) ///
		if country=="GBR" & party_id!=401 & party_id!=404, by(party_id, ///
		note("") title(United Kingdom)) ytitle(Opposition Party Behaviour) xtitle("")
graph save uk_covid.gph, replace
graph export uk_covid.png, replace


*** Analyses

* Only date
reg date_position date_or datesq_or ib4.country_id, cluster(party_id)
outreg2 using covid_analyses_october.doc, replace dec(3) ctitle(Baseline) label alpha(0.01, 0.05, 0.1) symbol(**, *, †)

* Only covid numbers, stringency and date
reg date_position  daily_permil dailydeaths_permil grsi ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_analyses_october.doc, append dec(3) ctitle(Crisis stage) label alpha(0.01, 0.05, 0.1) symbol(**, *, †)

* With ideology
reg date_position date_or datesq_or daily_permil dailydeaths_permil grsi lr_dist ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_analyses_october.doc, append dec(3) ctitle(Ideology) label alpha(0.01, 0.05, 0.1) symbol(**, *, †)

* Size and Experience
reg date_position date_or datesq_or daily_permil dailydeaths_permil grsi c.ge_years##c.party_size ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_analyses_october.doc, append dec(3) ctitle(Gov. Exp. * Size) label alpha(0.01, 0.05, 0.1) symbol(**, *, †)

* Full model
reg date_position date_or datesq_or daily_permil dailydeaths_permil grsi lr_dist c.ge_years##c.party_size ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_analyses_october.doc, append dec(3) ctitle(Full model) label alpha(0.01, 0.05, 0.1) symbol(**, *, †)
margins, dydx(party_size) at (ge_years = (0 (4) 20))
marginsplot, scheme(s1mono)  ///
	ytitle("Effect of party size on DV") ///
	xtitle("Office experience (years)") ///
	title("")  yline(0) ///
	addplot(hist ge_years, yaxis(2) yscale(axis(2) alt) ///
	fintensity(inten30) color(%30) legend(off) ytitle("Density of government experience", axis(2) size(small)) xlabel(0 (4) 20))	

graph save interaction_size_full.gph, replace

margins, dydx(ge_years) at (party_size = (0 (8) 32))
marginsplot, scheme(s1mono)  ///
	ytitle("Effect of office experience on DV") ///
	xtitle("Party size") ///
	title("")  yline(0) ///
	addplot(hist party_size, yaxis(2) yscale(axis(2) alt) ///
	fintensity(inten30) color(%30) legend(off) ytitle("Density of party size", axis(2) size(small)) xlabel(0 (6) 32))	


graph save interaction_exp_full.gph, replace

graph combine interaction_size_full.gph interaction_exp_full.gph, col(2) ycommon
graph export interaction_full.png, replace


*** Robustness ***

* Populism scale
reg date_position date_or datesq_or daily_permil dailydeaths_permil grsi lr_dist populism c.ge_years##c.party_size ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_robustness.doc, replace dec(3) ctitle(Populism scale) label

* Populism dummy
reg date_position date_or datesq_or daily_permil dailydeaths_permil grsi lr_dist populist c.ge_years##c.party_size ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_robustness.doc, append dec(3) ctitle(Populism binary) label


reg date_position  daily_permil  ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_robustness.doc, append dec(3) ctitle(Daily cases) label


reg date_position  dailydeaths_permil  ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_robustness.doc, append dec(3) ctitle(Daily deaths) label

reg date_position  grsi  ib4.country_id ///
		, cluster(party_id)
outreg2 using covid_robustness.doc, append dec(3) ctitle(Stringency) label


*** Multilevel analysis

use multilevel_nov20.dta, clear

xtmixed score interruption words date_or datesq_or daily* grsi lr_dist c.ge_years##c.party_size, var || party_id: || speaker_id:
outreg2 using covid_multilevel, word dec(3) replace label alpha(0.01, 0.05, 0.1) symbol(**, *, †)
estat icc

